Learn R Programming

ibd (version 1.0)

design_to_N: block design to incidence matrix

Description

This function generates incidence matrix from a given block design

Usage

design_to_N(design)

Arguments

design
design

Value

  • NA treatment by block incidence matrix of order v by b with elements as 0 and 1 where v is number of treatments and b is number of blocks

Examples

Run this code
d=matrix(c(1	,	4	,	6	,
5	,	6	,	7	,
3	,	4	,	5	,
2	,	4	,	7	,
1	,	3	,	7	,
2	,	3	,	6	,
1	,	2	,	5	
),nrow=7,byrow=TRUE)
design_to_N(d)

Run the code above in your browser using DataLab